#version 430

layout(binding = 0, std140) uniform UBO
{
    mat4 MVP;
    vec4 SourceSize;
    vec4 OriginalSize;
    vec4 OutputSize;
    uint FrameCount;
    float bloom;
    float halation;
    float slotms;
    float mclip;
    float mask_gamma;
    float gamma_out;
    float overscanX;
    float overscanY;
    float intres;
    float prescalex;
    float c_shape;
    float barspeed;
    float barintensity;
    float bardir;
    float sborder;
    float bloom_dist;
    float deconr;
    float decons;
    float addnoised;
    float noisetype;
    float noiseresd;
    float deconrr;
    float deconrg;
    float deconrb;
    float deconrry;
    float deconrgy;
    float deconrby;
    float dctypex;
    float dctypey;
    float post_br;
} global;

struct Push
{
    float TATE;
    float IOS;
    float OS;
    float BLOOM;
    float brightboost;
    float brightboost1;
    float csize;
    float bsize1;
    float warpX;
    float warpY;
    float glow;
    float shadowMask;
    float masksize;
    float slotmask;
    float slotmask1;
    float slotwidth;
    float double_slot;
    float mcut;
    float maskDark;
    float maskLight;
    float maskstr;
    float mshift;
    float mask_layout;
};

uniform Push params;

layout(binding = 7) uniform sampler2D Source;
layout(binding = 5) uniform sampler2D BloomPass;
layout(binding = 3) uniform sampler2D AvgLumPass;
layout(binding = 2) uniform sampler2D LinearizePass;
layout(binding = 4) uniform sampler2D GlowPass;
layout(binding = 6) uniform sampler2D PrePass;

layout(location = 0) in vec2 vTexCoord;
layout(location = 0) out vec4 FragColor;

vec2 Overscan(inout vec2 pos, float dx, float dy)
{
    pos = (pos * 2.0) - vec2(1.0);
    pos *= vec2(dx, dy);
    return (pos * 0.5) + vec2(0.5);
}

vec2 Warp(inout vec2 pos)
{
    pos = (pos * 2.0) - vec2(1.0);
    pos = mix(pos, vec2(pos.x * inversesqrt(1.0 - ((global.c_shape * pos.y) * pos.y)), pos.y * inversesqrt(1.0 - ((global.c_shape * pos.x) * pos.x))), vec2(params.warpX, params.warpY) / vec2(global.c_shape));
    return (pos * 0.5) + vec2(0.5);
}

void fetch_pixel(inout vec3 c, inout vec3 b, vec2 coord, vec2 bcoord)
{
    float stepx = global.OutputSize.z;
    float stepy = global.OutputSize.w;
    float ds = global.decons;
    vec2 dx = vec2(stepx, 0.0);
    vec2 dy = vec2(0.0, stepy);
    float posx = (2.0 * coord.x) - 1.0;
    float posy = (2.0 * coord.y) - 1.0;
    if (global.dctypex > 0.02500000037252902984619140625)
    {
        posx = sign(posx) * pow(abs(posx), 1.0499999523162841796875 - global.dctypex);
        dx *= posx;
    }
    if (global.dctypey > 0.02500000037252902984619140625)
    {
        posy = sign(posy) * pow(abs(posy), 1.0499999523162841796875 - global.dctypey);
        dy *= posy;
    }
    vec2 rc = (dx * global.deconrr) + (dy * global.deconrry);
    vec2 gc = (dx * global.deconrg) + (dy * global.deconrgy);
    vec2 bc = (dx * global.deconrb) + (dy * global.deconrby);
    float r1 = texture(Source, coord + rc).x;
    float g1 = texture(Source, coord + gc).y;
    float b1 = texture(Source, coord + bc).z;
    vec3 d = vec3(r1, g1, b1);
    c = clamp(mix(c, d, vec3(ds)), vec3(0.0), vec3(1.0));
    r1 = texture(BloomPass, bcoord + rc).x;
    g1 = texture(BloomPass, bcoord + gc).y;
    b1 = texture(BloomPass, bcoord + bc).z;
    d = vec3(r1, g1, b1);
    b = clamp(mix(b, d, vec3(ds)), vec3(0.0), vec3(1.0));
}

float SlotMask(inout vec2 pos, float m)
{
    if ((params.slotmask + params.slotmask1) == 0.0)
    {
        return 1.0;
    }
    else
    {
        pos = floor(pos / vec2(global.slotms));
        float mlen = params.slotwidth * 2.0;
        float px = fract(pos.x / mlen);
        float py = floor((fract(pos.y / (2.0 * params.double_slot)) * 2.0) * params.double_slot);
        float slot_dark = mix(1.0 - params.slotmask1, 1.0 - params.slotmask, m);
        float slot = 1.0;
        if ((py == 0.0) && (px < 0.5))
        {
            slot = slot_dark;
        }
        else
        {
            if ((py == params.double_slot) && (px >= 0.5))
            {
                slot = slot_dark;
            }
        }
        return slot;
    }
}

vec3 Mask(inout vec2 pos, float mx)
{
    vec2 pos0 = pos;
    pos.y = floor(pos.y / params.masksize);
    float next_line = float(fract(pos.y * 0.5) > 0.25);
    pos0.x += (next_line * params.mshift);
    pos = floor(pos0 / vec2(params.masksize));
    vec3 mask = vec3(params.maskDark, params.maskDark, params.maskDark);
    vec3 one = vec3(1.0);
    float dark_compensate = mix(max(clamp(mix(params.mcut, params.maskstr, mx), 0.0, 1.0) - 0.4000000059604644775390625, 0.0) + 1.0, 1.0, mx);
    float mc = 1.0 - max(params.maskstr, 0.0);
    if (params.shadowMask == (-1.0))
    {
        mask = vec3(1.0);
    }
    else
    {
        if (params.shadowMask == 0.0)
        {
            pos.x = fract(pos.x * 0.5);
            if (pos.x < 0.4900000095367431640625)
            {
                mask.x = 1.0;
                mask.y = mc;
                mask.z = 1.0;
            }
            else
            {
                mask.x = mc;
                mask.y = 1.0;
                mask.z = mc;
            }
        }
        else
        {
            if (params.shadowMask == 1.0)
            {
                float line = params.maskLight;
                float odd = 0.0;
                if (fract(pos.x / 6.0) < 0.4900000095367431640625)
                {
                    odd = 1.0;
                }
                if (fract((pos.y + odd) / 2.0) < 0.4900000095367431640625)
                {
                    line = params.maskDark;
                }
                pos.x = fract(pos.x / 3.0);
                if (pos.x < 0.300000011920928955078125)
                {
                    mask.x = params.maskLight;
                }
                else
                {
                    if (pos.x < 0.60000002384185791015625)
                    {
                        mask.y = params.maskLight;
                    }
                    else
                    {
                        mask.z = params.maskLight;
                    }
                }
                mask *= line;
            }
            else
            {
                if (params.shadowMask == 2.0)
                {
                    pos.x = fract(pos.x / 3.0);
                    if (pos.x < 0.300000011920928955078125)
                    {
                        mask.x = params.maskLight;
                    }
                    else
                    {
                        if (pos.x < 0.60000002384185791015625)
                        {
                            mask.y = params.maskLight;
                        }
                        else
                        {
                            mask.z = params.maskLight;
                        }
                    }
                }
                else
                {
                    if (params.shadowMask == 3.0)
                    {
                        pos.x += (pos.y * 3.0);
                        pos.x = fract(pos.x / 6.0);
                        if (pos.x < 0.300000011920928955078125)
                        {
                            mask.x = params.maskLight;
                        }
                        else
                        {
                            if (pos.x < 0.60000002384185791015625)
                            {
                                mask.y = params.maskLight;
                            }
                            else
                            {
                                mask.z = params.maskLight;
                            }
                        }
                    }
                    else
                    {
                        if (params.shadowMask == 4.0)
                        {
                            pos = floor(pos * vec2(1.0, 0.5));
                            pos.x += (pos.y * 3.0);
                            pos.x = fract(pos.x / 6.0);
                            if (pos.x < 0.300000011920928955078125)
                            {
                                mask.x = params.maskLight;
                            }
                            else
                            {
                                if (pos.x < 0.60000002384185791015625)
                                {
                                    mask.y = params.maskLight;
                                }
                                else
                                {
                                    mask.z = params.maskLight;
                                }
                            }
                        }
                        else
                        {
                            if (params.shadowMask == 5.0)
                            {
                                mask = vec3(0.0);
                                pos.x = fract(pos.x / 2.0);
                                if (pos.x < 0.4900000095367431640625)
                                {
                                    mask.x = 1.0;
                                    mask.z = 1.0;
                                }
                                else
                                {
                                    mask.y = 1.0;
                                }
                                mask = clamp(mix(mix(one, mask, vec3(params.mcut)), mix(one, mask, vec3(params.maskstr)), vec3(mx)), vec3(0.0), vec3(1.0)) * dark_compensate;
                            }
                            else
                            {
                                if (params.shadowMask == 6.0)
                                {
                                    mask = vec3(0.0);
                                    pos.x = fract(pos.x / 3.0);
                                    if (pos.x < 0.300000011920928955078125)
                                    {
                                        mask.x = 1.0;
                                    }
                                    else
                                    {
                                        if (pos.x < 0.60000002384185791015625)
                                        {
                                            mask.y = 1.0;
                                        }
                                        else
                                        {
                                            mask.z = 1.0;
                                        }
                                    }
                                    mask = clamp(mix(mix(one, mask, vec3(params.mcut)), mix(one, mask, vec3(params.maskstr)), vec3(mx)), vec3(0.0), vec3(1.0)) * dark_compensate;
                                }
                                else
                                {
                                    if (params.shadowMask == 7.0)
                                    {
                                        mask = vec3(0.0);
                                        pos.x = fract(pos.x / 2.0);
                                        if (pos.x < 0.4900000095367431640625)
                                        {
                                            mask = vec3(0.0);
                                        }
                                        else
                                        {
                                            mask = vec3(1.0);
                                        }
                                        mask = clamp(mix(mix(one, mask, vec3(params.mcut)), mix(one, mask, vec3(params.maskstr)), vec3(mx)), vec3(0.0), vec3(1.0)) * dark_compensate;
                                    }
                                    else
                                    {
                                        if (params.shadowMask == 8.0)
                                        {
                                            mask = vec3(0.0);
                                            pos.x = fract(pos.x / 3.0);
                                            if (pos.x < 0.300000011920928955078125)
                                            {
                                                mask = vec3(0.0);
                                            }
                                            else
                                            {
                                                if (pos.x < 0.60000002384185791015625)
                                                {
                                                    mask = vec3(1.0);
                                                }
                                                else
                                                {
                                                    mask = vec3(1.0);
                                                }
                                            }
                                            mask = clamp(mix(mix(one, mask, vec3(params.mcut)), mix(one, mask, vec3(params.maskstr)), vec3(mx)), vec3(0.0), vec3(1.0)) * dark_compensate;
                                        }
                                        else
                                        {
                                            if (params.shadowMask == 9.0)
                                            {
                                                mask = vec3(0.0);
                                                pos.x = fract(pos.x / 3.0);
                                                if (pos.x < 0.300000011920928955078125)
                                                {
                                                    mask = vec3(0.0);
                                                }
                                                else
                                                {
                                                    if (pos.x < 0.60000002384185791015625)
                                                    {
                                                        mask.x = 1.0;
                                                        mask.z = 1.0;
                                                    }
                                                    else
                                                    {
                                                        mask.y = 1.0;
                                                    }
                                                }
                                                mask = clamp(mix(mix(one, mask, vec3(params.mcut)), mix(one, mask, vec3(params.maskstr)), vec3(mx)), vec3(0.0), vec3(1.0)) * dark_compensate;
                                            }
                                            else
                                            {
                                                if (params.shadowMask == 10.0)
                                                {
                                                    mask = vec3(0.0);
                                                    pos.x = fract(pos.x * 0.25);
                                                    if (pos.x < 0.20000000298023223876953125)
                                                    {
                                                        mask = vec3(0.0);
                                                    }
                                                    else
                                                    {
                                                        if (pos.x < 0.4000000059604644775390625)
                                                        {
                                                            mask.x = 1.0;
                                                        }
                                                        else
                                                        {
                                                            if (pos.x < 0.699999988079071044921875)
                                                            {
                                                                mask.y = 1.0;
                                                            }
                                                            else
                                                            {
                                                                mask.z = 1.0;
                                                            }
                                                        }
                                                    }
                                                    mask = clamp(mix(mix(one, mask, vec3(params.mcut)), mix(one, mask, vec3(params.maskstr)), vec3(mx)), vec3(0.0), vec3(1.0)) * dark_compensate;
                                                }
                                                else
                                                {
                                                    if (params.shadowMask == 11.0)
                                                    {
                                                        mask = vec3(mc);
                                                        pos.x = fract(pos.x * 0.25);
                                                        if (pos.x < 0.20000000298023223876953125)
                                                        {
                                                            mask.x = 1.0;
                                                        }
                                                        else
                                                        {
                                                            if (pos.x < 0.4000000059604644775390625)
                                                            {
                                                                mask.x = 1.0;
                                                                mask.y = 1.0;
                                                            }
                                                            else
                                                            {
                                                                if (pos.x < 0.699999988079071044921875)
                                                                {
                                                                    mask.y = 1.0;
                                                                    mask.z = 1.0;
                                                                }
                                                                else
                                                                {
                                                                    mask.z = 1.0;
                                                                }
                                                            }
                                                        }
                                                    }
                                                    else
                                                    {
                                                        if (params.shadowMask == 12.0)
                                                        {
                                                            mask = vec3(mc);
                                                            pos.x = fract(pos.x * 0.25);
                                                            if (pos.x < 0.20000000298023223876953125)
                                                            {
                                                                mask.x = 1.0;
                                                            }
                                                            else
                                                            {
                                                                if (pos.x < 0.4000000059604644775390625)
                                                                {
                                                                    mask.x = 1.0;
                                                                    mask.z = 1.0;
                                                                }
                                                                else
                                                                {
                                                                    if (pos.x < 0.699999988079071044921875)
                                                                    {
                                                                        mask.y = 1.0;
                                                                        mask.z = 1.0;
                                                                    }
                                                                    else
                                                                    {
                                                                        mask.y = 1.0;
                                                                    }
                                                                }
                                                            }
                                                        }
                                                        else
                                                        {
                                                            mask = vec3(0.0);
                                                            pos.x = floor(mod(pos.x, 7.0));
                                                            if (pos.x < 1.0)
                                                            {
                                                                mask = vec3(0.0);
                                                            }
                                                            else
                                                            {
                                                                if (pos.x < 3.0)
                                                                {
                                                                    mask.x = 1.0;
                                                                }
                                                                else
                                                                {
                                                                    if (pos.x < 5.0)
                                                                    {
                                                                        mask.y = 1.0;
                                                                    }
                                                                    else
                                                                    {
                                                                        mask.z = 1.0;
                                                                    }
                                                                }
                                                            }
                                                            mask = clamp(mix(mix(one, mask, vec3(params.mcut)), mix(one, mask, vec3(params.maskstr)), vec3(mx)), vec3(0.0), vec3(1.0)) * dark_compensate;
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }
    return mask;
}

vec3 plant(vec3 tar, float r)
{
    float t = max(max(tar.x, tar.y), tar.z) + 9.9999997473787516355514526367188e-06;
    return (tar * r) / vec3(t);
}

vec3 declip(inout vec3 c, float b)
{
    float m = max(max(c.x, c.y), c.z);
    if (m > b)
    {
        c = (c * b) / vec3(m);
    }
    return c;
}

vec3 _noise(inout vec3 v)
{
    if (global.addnoised < 0.0)
    {
        v.z = -global.addnoised;
    }
    else
    {
        v.z /= 6000.0;
    }
    v = (fract(v) + fract(v * 10000.0)) + fract(v * 9.9999997473787516355514526367188e-05);
    v += vec3(0.123450003564357757568359375, 0.6789000034332275390625, 0.3141590058803558349609375);
    v = fract((v * dot(v, v)) * 123.45600128173828125);
    v = fract((v * dot(v, v)) * 123.45600128173828125);
    v = fract((v * dot(v, v)) * 123.45600128173828125);
    return v;
}

float humbar(inout float pos)
{
    if (global.barintensity == 0.0)
    {
        return 1.0;
    }
    else
    {
        float _916;
        if (global.barintensity >= 0.0)
        {
            _916 = pos;
        }
        else
        {
            _916 = 1.0 - pos;
        }
        pos = _916;
        pos = fract(pos + (mod(float(global.FrameCount), global.barspeed) / (global.barspeed - 1.0)));
        float _942;
        if (global.barintensity < 0.0)
        {
            _942 = pos;
        }
        else
        {
            _942 = 1.0 - pos;
        }
        pos = _942;
        return (1.0 - global.barintensity) + (global.barintensity * pos);
    }
}

float corner(inout vec2 pos)
{
    vec2 b = (vec2(params.bsize1, params.bsize1) * vec2(1.0, global.OutputSize.x / global.OutputSize.y)) * 0.0500000007450580596923828125;
    pos = clamp(pos, vec2(0.0), vec2(1.0));
    pos = abs((pos - vec2(0.5)) * 2.0);
    float csize1 = mix(400.0, 7.0, pow(4.0 * params.csize, 0.100000001490116119384765625));
    float crn = dot(pow(pos, vec2(csize1)), vec2(1.0, global.OutputSize.y / global.OutputSize.x));
    float _1009;
    if (params.csize == 0.0)
    {
        _1009 = max(pos.x, pos.y);
    }
    else
    {
        _1009 = pow(crn, 1.0 / csize1);
    }
    crn = _1009;
    pos = max(pos, vec2(crn));
    vec2 _1031;
    if (params.bsize1 == 0.0)
    {
        _1031 = vec2(1.0);
    }
    else
    {
        _1031 = mix(vec2(0.0), vec2(1.0), smoothstep(vec2(1.0), vec2(1.0) - b, sqrt(pos)));
    }
    vec2 res = _1031;
    res = pow(res, vec2(global.sborder));
    return sqrt(res.x * res.y);
}

void main()
{
    vec4 SourceSize = global.OriginalSize * vec4(global.prescalex, 1.0, 1.0 / global.prescalex, 1.0);
    float lum = texture(AvgLumPass, vec2(0.5)).w;
    float gamma_in = 1.0 / texture(LinearizePass, vec2(0.25)).w;
    float intera = texture(LinearizePass, vec2(0.75, 0.25)).w;
    bool interb = intera < 0.5;
    bool notate = params.TATE < 0.5;
    vec2 texcoord = vTexCoord;
    if ((params.IOS > 0.0) && (!interb))
    {
        vec2 ofactor = global.OutputSize.xy / SourceSize.xy;
        vec2 _1393;
        if (params.IOS < 2.5)
        {
            _1393 = floor(ofactor);
        }
        else
        {
            _1393 = ceil(ofactor);
        }
        vec2 intfactor = _1393;
        vec2 diff = ofactor / intfactor;
        float scan = mix(diff.y, diff.x, params.TATE);
        vec2 param = texcoord;
        float param_1 = scan;
        float param_2 = scan;
        vec2 _1420 = Overscan(param, param_1, param_2);
        texcoord = _1420;
        bool _1423 = params.IOS == 1.0;
        bool _1430;
        if (!_1423)
        {
            _1430 = params.IOS == 3.0;
        }
        else
        {
            _1430 = _1423;
        }
        if (_1430)
        {
            texcoord = mix(vec2(vTexCoord.x, texcoord.y), vec2(texcoord.x, vTexCoord.y), vec2(params.TATE));
        }
    }
    float factor = (1.0 + (((1.0 - (0.5 * params.OS)) * params.BLOOM) / 100.0)) - ((lum * params.BLOOM) / 100.0);
    vec2 param_3 = texcoord;
    float param_4 = factor;
    float param_5 = factor;
    vec2 _1471 = Overscan(param_3, param_4, param_5);
    texcoord = _1471;
    vec2 param_6 = texcoord;
    float param_7 = (SourceSize.x - global.overscanX) / SourceSize.x;
    float param_8 = (SourceSize.y - global.overscanY) / SourceSize.y;
    vec2 _1492 = Overscan(param_6, param_7, param_8);
    texcoord = _1492;
    vec2 pos1 = vTexCoord;
    vec2 param_9 = texcoord;
    vec2 _1498 = Warp(param_9);
    vec2 pos = _1498;
    vec2 param_10 = vTexCoord;
    vec2 _1502 = Warp(param_10);
    vec2 pos0 = _1502;
    vec3 color0 = texture(Source, pos1).xyz;
    float c0 = max(max(color0.x, color0.y), color0.z);
    vec3 color = texture(Source, pos1).xyz;
    vec3 Bloom = texture(BloomPass, pos).xyz;
    vec3 param_11 = color;
    vec3 param_12 = Bloom;
    vec2 param_13 = pos1;
    vec2 param_14 = pos;
    fetch_pixel(param_11, param_12, param_13, param_14);
    color = param_11;
    Bloom = param_12;
    float cm = max(max(color.x, color.y), color.z);
    float mx1 = texture(Source, pos1).w;
    float colmx = max(mx1, cm);
    float w3 = min((c0 + 0.0005000000237487256526947021484375) / (pow(colmx, gamma_in / 1.39999997615814208984375) + 0.0005000000237487256526947021484375), 1.0);
    vec2 dx = mix(vec2(0.000750000006519258022308349609375, 0.0), vec2(0.0, 0.000750000006519258022308349609375), vec2(params.TATE));
    float mx0 = texture(Source, pos1 - dx).w;
    float mx2 = texture(Source, pos1 + dx).w;
    float mx = max(max(mx0, mx1), max(mx2, cm));
    vec3 one = vec3(1.0);
    vec3 orig1 = color;
    vec3 cmask = one;
    vec2 maskcoord = (vTexCoord * global.OutputSize.xy).yx * 1.00000095367431640625;
    if (notate)
    {
        maskcoord = maskcoord.yx;
    }
    vec2 param_15 = maskcoord;
    float param_16 = mx;
    float _1622 = SlotMask(param_15, param_16);
    float smask = _1622;
    vec2 param_17 = maskcoord;
    float param_18 = mx;
    vec3 _1627 = Mask(param_17, param_18);
    cmask *= _1627;
    if (params.mask_layout > 0.5)
    {
        cmask = cmask.xzy;
    }
    color = pow(color, vec3(global.mask_gamma / gamma_in));
    color *= cmask;
    color = min(color, vec3(1.0));
    color *= smask;
    color = pow(color, vec3(gamma_in / global.mask_gamma));
    cmask = min(cmask * smask, vec3(1.0));
    float bb = mix(params.brightboost, params.brightboost1, colmx);
    if (interb)
    {
        float _1680;
        if (abs(intera - 0.5) < 0.100000001490116119384765625)
        {
            _1680 = pow(0.800000011920928955078125 * bb, 0.64999997615814208984375);
        }
        else
        {
            _1680 = pow(bb, 0.699999988079071044921875);
        }
        bb = _1680;
    }
    color *= bb;
    vec3 Glow = texture(GlowPass, pos).xyz;
    vec3 Ref = texture(LinearizePass, pos).xyz;
    float maxb = texture(BloomPass, pos).w;
    float vig = texture(PrePass, clamp(pos, vec2(0.0) + (global.OriginalSize.zw * 0.5), vec2(1.0) - (global.OriginalSize.zw * 0.5))).w;
    vec3 Bloom1 = Bloom;
    if (global.bloom < (-0.00999999977648258209228515625))
    {
        vec3 param_19 = Bloom;
        float param_20 = maxb;
        Bloom1 = plant(param_19, param_20);
    }
    Bloom1 = min(Bloom1 * (orig1 + color), max(((vec3(colmx) + orig1) - color) * 0.5, Bloom1 * 0.001000000047497451305389404296875));
    Bloom1 = (Bloom1 + mix(Bloom1, mix(orig1 * colmx, Bloom1, vec3(0.5)), vec3(1.0) - color)) * 0.5;
    Bloom1 *= mix(1.0, 2.0 - colmx, global.bloom_dist);
    color += (Bloom1 * abs(global.bloom));
    color = min(color, mix(one, cmask, vec3(global.mclip)));
    if (!interb)
    {
        vec3 param_21 = color;
        float param_22 = mix(1.0, w3, 0.60000002384185791015625);
        vec3 _1805 = declip(param_21, param_22);
        color = _1805;
    }
    else
    {
        w3 = 1.0;
    }
    if (global.halation > 0.00999999977648258209228515625)
    {
        Bloom = mix((Bloom + (Bloom * Bloom)) * 0.5, (Bloom * 0.75) * Bloom, vec3(colmx));
        color += (((mix(one, cmask, vec3(0.60000002384185791015625)) * ((2.0 * max((maxb + (maxb * maxb)) - (0.5 * max(max(Ref.x, Ref.y), Ref.z)), 0.25)) * mix(1.0, w3, 0.5 * colmx))) * Bloom) * global.halation);
    }
    Glow = mix(Glow, color * 0.25, vec3(0.699999988079071044921875 * colmx));
    if (params.glow >= 0.0)
    {
        color += ((Glow * 0.5) * params.glow);
    }
    else
    {
        cmask *= cmask;
        cmask *= cmask;
        color += ((cmask * (-params.glow)) * Glow);
    }
    color = min(color, vec3(1.0));
    color = pow(color, vec3(1.0 / global.gamma_out));
    float rc = (0.60000002384185791015625 * sqrt(max(max(color.x, color.y), color.z))) + 0.4000000059604644775390625;
    if (abs(global.addnoised) > 0.00999999977648258209228515625)
    {
        vec3 param_23 = vec3(floor((global.OutputSize.xy * vTexCoord) / vec2(global.noiseresd)), float(global.FrameCount));
        vec3 _1942 = _noise(param_23);
        vec3 noise0 = _1942;
        if (global.noisetype < 0.5)
        {
            color = mix(color, noise0, vec3((0.25 * abs(global.addnoised)) * rc));
        }
        else
        {
            color = min(color * mix(1.0, 1.5 * noise0.x, 0.5 * abs(global.addnoised)), vec3(1.0));
        }
    }
    float param_24 = mix(pos.y, pos.x, global.bardir);
    float _1986 = humbar(param_24);
    vec2 param_25 = pos0;
    float _1994 = corner(param_25);
    FragColor = vec4((((color * vig) * _1986) * global.post_br) * _1994, 1.0);
}

